from setuptools import setup, find_packages

setup(
    name='freo',
    version='8.2.4',
    packages=find_packages(include=['freo', 'freo.*']),
    description='This is the almighty freo package'
)
